==> haskell-pandoc-lua-engine-0.2.1.2-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-engine
version:              0.2.1.2
visibility:           public
id:                   pandoc-lua-engine-0.2.1.2-9E1T1bOmjDY3xIORd63yem
key:                  pandoc-lua-engine-0.2.1.2-9E1T1bOmjDY3xIORd63yem
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  5d69b47fccfd6ded8ab9ebce0878678d
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.2-9E1T1bOmjDY3xIORd63yem
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    aeson-2.1.2.1-9T6l6SxZl5u1C3PaFHxalW base-4.16.4.0
    bytestring-0.11.4.0 citeproc-0.8.1-36mgTkVmN6kDynDBzqlhCN
    containers-0.6.5.1 data-default-0.7.1.1-4Q2QEONQl2rBpJbSE6OFE3
    doclayout-0.4.0.1-5x4V5qRO2VTHqry3rqZIoq
    doctemplates-0.11-2PEcPknJX7T2sNZJVPCJFw exceptions-0.10.4
    hslua-2.3.0-JzR7TWiArMY7fO0NFAFABA
    hslua-module-doclayout-1.1.0-LpTFmBQ22Av1oeAHiKo7CK
    hslua-module-path-1.1.0-AMrwCKSneu7Brr5FtbXiOz
    hslua-module-system-1.1.0.1-HKLVcwF9H7VBmYYoHrcF5P
    hslua-module-text-1.1.0.1-69L8PHx42kRDJizxeqzB1b
    hslua-module-version-1.1.1-3GF2rRomQudHnIsXhOYUx7
    hslua-module-zip-1.1.1-9miBQjcWhunKFJwcJHuJfn
    hslua-repl-0.1.2-9ot5Yv2Bu4tK29gRc0cGHc
    lpeg-1.0.4-IvlMU8t018Y6DRGcg5379f mtl-2.2.2
    pandoc-3.1.12.1-EivjFg83Nmj1bOm6apONAx
    pandoc-lua-marshal-0.2.7-24bZPgJH6GGLl8kyLkK2cR
    pandoc-types-1.23.1-AQnuN9AUT1M2gVSZkxtfP0 parsec-3.1.15.0
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pandoc-lua-engine-0.2.1.2-83-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pandoc-lua-engine.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pandoc-lua-engine
version:              0.2.1.2
visibility:           public
id:                   pandoc-lua-engine-0.2.1.2-EWz5DiI7RHlDxUL2BDRBzN
key:                  pandoc-lua-engine-0.2.1.2-EWz5DiI7RHlDxUL2BDRBzN
license:              GPL-2.0-or-later
copyright:            © 2006-2022 John MacFarlane, 2017-2022 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@hslua.org>
author:               John MacFarlane, Albert Krewinkel
homepage:             https://pandoc.org
synopsis:             Lua engine to power custom pandoc conversions
description:
    This package provides a pandoc scripting engine based on
    Lua.

category:             Text
abi:                  41b368e16f1d28ba1996e65c021b5938
exposed:              True
exposed-modules:      Text.Pandoc.Lua
hidden-modules:
    Text.Pandoc.Lua.Custom Text.Pandoc.Lua.Filter
    Text.Pandoc.Lua.Global Text.Pandoc.Lua.Init
    Text.Pandoc.Lua.Marshal.Chunks Text.Pandoc.Lua.Marshal.CommonState
    Text.Pandoc.Lua.Marshal.Context Text.Pandoc.Lua.Marshal.Format
    Text.Pandoc.Lua.Marshal.PandocError
    Text.Pandoc.Lua.Marshal.ReaderOptions
    Text.Pandoc.Lua.Marshal.Reference Text.Pandoc.Lua.Marshal.Sources
    Text.Pandoc.Lua.Marshal.Template
    Text.Pandoc.Lua.Marshal.WriterOptions Text.Pandoc.Lua.Module.CLI
    Text.Pandoc.Lua.Module.Format Text.Pandoc.Lua.Module.JSON
    Text.Pandoc.Lua.Module.MediaBag Text.Pandoc.Lua.Module.Pandoc
    Text.Pandoc.Lua.Module.Scaffolding Text.Pandoc.Lua.Module.Structure
    Text.Pandoc.Lua.Module.System Text.Pandoc.Lua.Module.Template
    Text.Pandoc.Lua.Module.Text Text.Pandoc.Lua.Module.Types
    Text.Pandoc.Lua.Module.Utils Text.Pandoc.Lua.Orphans
    Text.Pandoc.Lua.PandocLua Text.Pandoc.Lua.Writer.Classic
    Text.Pandoc.Lua.Writer.Scaffolding

import-dirs:          /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/pandoc-lua-engine-0.2.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-pandoc-lua-engine
hs-libraries:         HSpandoc-lua-engine-0.2.1.2-EWz5DiI7RHlDxUL2BDRBzN
depends:
    SHA-1.6.4.4-4vZ3YEU9upt6TqgW7hflaa
    aeson-2.1.2.1-A1BsFbrv9iTYSCFmVNKuj base-4.16.4.0
    bytestring-0.11.4.0 citeproc-0.8.1-F0dYYW5QAktH1NX6fHVKfY
    containers-0.6.5.1 data-default-0.7.1.1-dedT9YOqsF2aVr3BjFeyL
    doclayout-0.4.0.1-HG2Ql9PinzaKvxBYcqLGw3
    doctemplates-0.11-6B0bCOLN5YOBXdndTzz2mj exceptions-0.10.4
    hslua-2.3.0-5PyA2c8reubE5iKOdnH6xM
    hslua-module-doclayout-1.1.0-GUelgcSfrykyrFgTfxH4G
    hslua-module-path-1.1.0-8adCY1qLbBtAy8xiZDrqVd
    hslua-module-system-1.1.0.1-ElMeqA2v8GYIypCpxKKLoa
    hslua-module-text-1.1.0.1-4tvYKZpq1qeD2WpsVrA5A9
    hslua-module-version-1.1.1-LenZTg8qZNH4tEMhx7CV07
    hslua-module-zip-1.1.1-6fWPHm7iWmy9na6k5p7org
    hslua-repl-0.1.2-9DG9MzyjUgUD7fC52ksJg4
    lpeg-1.0.4-JIugNHC5pW04kza4DVlBI4 mtl-2.2.2
    pandoc-3.1.12.1-3V9igos9mQsKBZn8Yu1wzl
    pandoc-lua-marshal-0.2.7-b8823Q779NFWA3lFOY9SC
    pandoc-types-1.23.1-7y4enX17Vss6sHXUsx5HTV parsec-3.1.15.0
    text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-pandoc-lua-engine/html/pandoc-lua-engine.haddock

haddock-html:         /usr/share/doc/haskell-pandoc-lua-engine/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
